@@ -67,7 +67,7 @@ class ImportContainer(BaseContainer):
                         if document['version'] != 1:
                             raise ValueError(f'Unknown container version {document["version"]}')
                         unknown_kinds = set(document['object_kinds']) - all_kinds
-                        if unknown_kinds:
+                        if unknown_kinds and not self.ignore_unknown:
                             raise ValueError(f'Unknown object types {unknown_kinds}')
                         self.metadata = document.get('metadata')
                         if self.metadata:
